@@ -18,4 +18,4 @@
 import context  # Ensures paho is in PYTHONPATH
 import paho.mqtt.publish as publish
 
-publish.single("paho/test/single", "boo", hostname="test.mosquitto.org")
+publish.single("paho/test/single", "boo", hostname="mqtt.eclipse.org")
